pub struct CsvParser<'de> { /* private fields */ }Expand description
CSV parser that emits FormatParser events.
CSV is parsed as a struct where each comma-separated field corresponds to a struct field in definition order. The format does not support nested structures or arrays.
Unlike fully self-describing formats (JSON), CSV is positional:
- Fields are identified by column order, not names
- The parser uses
hint_struct_fieldsto know how many fields to expect - Each field emits an
OrderedFieldevent followed by aScalarvalue
Implementations